Index: FCKeditor/trunk/_dev/releaser/fckreleaser.php
===================================================================
--- FCKeditor/trunk/_dev/releaser/fckreleaser.php	(revision 1973)
+++ FCKeditor/trunk/_dev/releaser/fckreleaser.php	(revision 1978)
@@ -1,3 +1,3 @@
-#!/usr/bin/php -q
+﻿#!/usr/bin/php -q
 <?php
 /*
@@ -128,5 +128,5 @@
 class FCKReleaser
 {
-	var $_PreProcessExtensions = array( 'js','html','asp','aspx','cfc','cfm','jsp','css','xml','txt','java','php','cgi','pl','lasso','py' ) ;
+	var $_PreProcessExtensions = array( 'js','html','asp','aspx','ascx','cfc','cfm','jsp','css','xml','txt','java','php','cgi','pl','lasso','py','config' ) ;
 
 	var $SourcesDir ;
@@ -627,7 +627,9 @@
 			' ', $script ) ;
 
 		// Concatenate lines that end with "}" using a ";" (except for "else" and "catch" cases).
 		$script = preg_replace(
-			'/\s*}\s*[\n\r]+\s*(?!\s*(else|catch|}))/s',
+			'/\s*}\s*[\n\r]+\s*(?!\s*(else|catch|finally|while|[}\),;]))/s',
 			'};', $script ) ;
 
@@ -627,7 +627,9 @@
 			' ', $script ) ;
 
-		// Concatenate lines that end with "}" using a ";" (except for "else" and "catch" cases).
+		// Concatenate lines that end with "}" using a ";", except for "else",
+		// "while", "catch" and "finally" cases, or when followed by, "'", ";",
+		// "}" or ")".
 		$script = preg_replace(
